# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['mistion', 'mistion.scripts']

package_data = \
{'': ['*']}

install_requires = \
['h5py>=3.4.0,<4.0.0',
 'iri2016>=1.11.1,<2.0.0',
 'matplotlib>=3.5.1,<4.0.0',
 'mpi4py>=3.1.2,<4.0.0',
 'pymap3d>=2.7.2,<3.0.0',
 'scipy>=1.7,<2.0',
 'tqdm>=4.62.3,<5.0.0']

setup_kwargs = {
    'name': 'mistion',
    'version': '0.3.2',
    'description': 'Ionosphere simulation for the MIST project',
    'long_description': "# mist_ion\nA fork of [mist_ionosphere](https://github.com/erika-hornecker/mist_ionosphere). \nMist_ion provides tools for ionosphere modeling (refraction angles, attenuation factors, etc.)\nfor the [MIST](http://www.physics.mcgill.ca/mist/) project. A more detailed overview will be \navailable soon.\n\n## Installing\nPrerequisites\n- MPI implementation, for example\n  - [Open MPI](https://www.open-mpi.org/) \n  - [MPICH](https://www.mpich.org/)\n  - [Microsoft MPI](https://docs.microsoft.com/en-us/message-passing-interface/microsoft-mpi) (for Windows)\n\nThen you can install the package via pip\n```\npython3 -m pip install mistion\n```\n\n[//]: # (## Quick example)\n\n[//]: # (```python)\n\n[//]: # (from mist_ion import IonModel)\n\n[//]: # (from datetime import datetime)\n\n[//]: # ()\n[//]: # (# Date and time of observation)\n\n[//]: # (dt = datetime.strptime&#40;'2012-08-15 06:00', '%Y-%m-%d %H:%M'&#41;)\n\n[//]: # ()\n[//]: # (# Initial model parameters: telescope position, frequency of observations, datetime)\n\n[//]: # (model = IonModel&#40;)\n\n[//]: # (    lat0=79.433,)\n\n[//]: # (    lon0=-90.766,)\n\n[//]: # (    alt0=0.,)\n\n[//]: # (    freq=45e6,)\n\n[//]: # (    dt=dt)\n\n[//]: # (&#41;)\n\n[//]: # ()\n[//]: # (# Create a grid of [gridsize x gridsize] points - azimuth and elevation &#40;telescope POV&#41;)\n\n[//]: # (model.generate_coord_grid&#40;gridsize=100&#41;)\n\n[//]: # ()\n[//]: # (# Setup D layer and F layer parameters &#40;number of sublayers, lower and upper limits in m&#41;)\n\n[//]: # (model.setup_dlayer&#40;nlayers=10, d_bot = 6e4, d_top = 9e4&#41;)\n\n[//]: # (model.setup_flayer&#40;nlayers=30&#41;)\n\n[//]: # ()\n[//]: # (# Starting calculation with 16 parallel processes)\n\n[//]: # (model.calc&#40;progressbar=True, processes=16&#41;)\n\n[//]: # ()\n[//]: # (# Saving results for later use)\n\n[//]: # (model.save&#40;name='test', dir='results'&#41;)\n\n[//]: # ()\n[//]: # (# Loading model)\n\n[//]: # (new_model = IonModel.load&#40;'results/test.h5'&#41;)\n\n[//]: # ()\n[//]: # (# Plotting results)\n\n[//]: # (model.plot&#40;data='d_e_density'&#41;)\n\n[//]: # ()\n[//]: # (# Plotting and saving results)\n\n[//]: # (model.plot&#40;data='d_e_density', file='d_e_density_plot.png'&#41;)\n\n[//]: # (```)",
    'author': 'lap1dem',
    'author_email': 'vadym.bidula@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/lap1dem/mist_ion',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<3.10',
}


setup(**setup_kwargs)
